function varargout = guide_test(varargin)
% GUIDE_TEST MATLAB code for guide_test.fig
%      GUIDE_TEST, by itself, creates a new GUIDE_TEST or raises the existing
%      singleton*.
%
%      H = GUIDE_TEST returns the handle to a new GUIDE_TEST or the handle to
%      the existing singleton*.
%
%      GUIDE_TEST('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GUIDE_TEST.M with the given input arguments.
%
%      GUIDE_TEST('Property','Value',...) creates a new GUIDE_TEST or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before guide_test_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to guide_test_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help guide_test

% Last Modified by GUIDE v2.5 04-Jan-2017 11:22:32

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @guide_test_OpeningFcn, ...
                   'gui_OutputFcn',  @guide_test_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before guide_test is made visible.
function guide_test_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to guide_test (see VARARGIN)

% Choose default command line output for guide_test
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes guide_test wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = guide_test_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
fig = get(hObject,'Parent');
set(fig,'Color',rand(1,3));
